# Description of Software Package #

Doobabee here be the steps yarr

## 1. Import

First, we import the file.

## 2. Process

Second, we process the file. 

## 3. Plotting

Third, we visualize the data.

The expected result is a comprehensible and presentable visualization of .fits data.
